==> com.liferay.account.admin.web-1.0.21-sources.jar: com/liferay/account/admin/web/internal/constants/AccountScreenNavigationEntryConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.account.admin.web.internal.constants;

/**
 * @author Albert Lee
 */
public class AccountScreenNavigationEntryConstants {

	public static final String CATEGORY_KEY_ASSIGNEES = "assignees";

	public static final String CATEGORY_KEY_CONTACT = "contact";

	public static final String CATEGORY_KEY_DEFINE_PERMISSIONS =
		"define-permissions";

	public static final String CATEGORY_KEY_DETAILS = "details";

	public static final String CATEGORY_KEY_GENERAL = "general";

	public static final String CATEGORY_KEY_ORGANIZATIONS = "organizations";

	public static final String CATEGORY_KEY_PREFERENCES = "preferences";

	public static final String CATEGORY_KEY_ROLES = "roles";

	public static final String CATEGORY_KEY_USERS = "users";

	public static final String ENTRY_KEY_ACCOUNTS = "accounts";

	public static final String ENTRY_KEY_ADDRESSES = "addresses";

	public static final String ENTRY_KEY_ALERTS_AND_ANNOUNCEMENTS_DELIVERY =
		"alerts-and-announcements-delivery";

	public static final String ENTRY_KEY_ASSIGNEES = "assignees";

	public static final String ENTRY_KEY_CONTACT_INFORMATION =
		"contact-information";

	public static final String ENTRY_KEY_DEFINE_PERMISSIONS =
		"define-permissions";

	public static final String ENTRY_KEY_DETAILS = "details";

	public static final String ENTRY_KEY_DISPLAY_SETTINGS = "display-settings";

	public static final String ENTRY_KEY_INFORMATION = "information";

	public static final String ENTRY_KEY_ORGANIZATIONS = "organizations";

	public static final String ENTRY_KEY_PASSWORD = "password";

	public static final String ENTRY_KEY_ROLES = "roles";

	public static final String ENTRY_KEY_USERS = "users";

	public static final String SCREEN_NAVIGATION_KEY_ACCOUNT_ENTRY =
		"edit.account.entry.form";

	public static final String SCREEN_NAVIGATION_KEY_ACCOUNT_ROLE =
		"edit.account.role.form";

	public static final String SCREEN_NAVIGATION_KEY_ACCOUNT_USER =
		"edit.account.user.form";

}

==> com.liferay.account.admin.web-2.0.13-sources.jar: com/liferay/account/admin/web/internal/constants/AccountScreenNavigationEntryConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.account.admin.web.internal.constants;

/**
 * @author Albert Lee
 */
public class AccountScreenNavigationEntryConstants {

	public static final String CATEGORY_KEY_ACCOUNT_GROUPS = "account-groups";

	public static final String CATEGORY_KEY_ACCOUNTS = "accounts";

	public static final String CATEGORY_KEY_ADDRESSES = "addresses";

	public static final String CATEGORY_KEY_ASSIGNEES = "assignees";

	public static final String CATEGORY_KEY_CONTACT = "contact";

	public static final String CATEGORY_KEY_DEFINE_GROUP_SCOPE_PERMISSIONS =
		"define-group-scope-permissions";

	public static final String CATEGORY_KEY_DEFINE_PERMISSIONS =
		"define-permissions";

	public static final String CATEGORY_KEY_DETAILS = "details";

	public static final String CATEGORY_KEY_GENERAL = "general";

	public static final String CATEGORY_KEY_ORGANIZATIONS = "organizations";

	public static final String CATEGORY_KEY_PREFERENCES = "preferences";

	public static final String CATEGORY_KEY_ROLES = "roles";

	public static final String CATEGORY_KEY_USERS = "users";

	public static final String ENTRY_KEY_ACCOUNT_GROUPS = "account-groups";

	public static final String ENTRY_KEY_ACCOUNTS = "accounts";

	public static final String ENTRY_KEY_ADDRESSES = "addresses";

	public static final String ENTRY_KEY_ALERTS_AND_ANNOUNCEMENTS_DELIVERY =
		"alerts-and-announcements-delivery";

	public static final String ENTRY_KEY_ASSIGNEES = "assignees";

	public static final String ENTRY_KEY_CONTACT_INFORMATION =
		"contact-information";

	public static final String ENTRY_KEY_DEFINE_GROUP_SCOPE_PERMISSIONS =
		"define-group-scope-permissions";

	public static final String ENTRY_KEY_DEFINE_PERMISSIONS =
		"define-permissions";

	public static final String ENTRY_KEY_DETAILS = "details";

	public static final String ENTRY_KEY_DISPLAY_SETTINGS = "display-settings";

	public static final String ENTRY_KEY_INFORMATION = "information";

	public static final String ENTRY_KEY_ORGANIZATIONS = "organizations";

	public static final String ENTRY_KEY_PASSWORD = "password";

	public static final String ENTRY_KEY_ROLES = "roles";

	public static final String ENTRY_KEY_USERS = "users";

	public static final String SCREEN_NAVIGATION_KEY_ACCOUNT_ENTRY =
		"edit.account.entry.form";

	public static final String SCREEN_NAVIGATION_KEY_ACCOUNT_GROUP =
		"edit.account.group.form";

	public static final String SCREEN_NAVIGATION_KEY_ACCOUNT_ROLE =
		"edit.account.role.form";

	public static final String SCREEN_NAVIGATION_KEY_ACCOUNT_USER =
		"edit.account.user.form";

}
